# aiompesa

A thin async wrapper of MPESA daraja API.

## Requirements

- Python 3.6+

## Installation

`$ pip install aiompesa`

## Motivation

- To learn a little more about `asyncio` and put it to some practise.
- To develop an async wrapper for the [Safaricom daraja api](https://developers.safaricom.co.ke)

## Contribution

Follow the [contribution guidelines](https://#)
